=== modified file 'analytic_distribution/account_bank_statement.py'
--- analytic_distribution/account_bank_statement.py	2011-09-21 13:47:13 +0000
+++ analytic_distribution/account_bank_statement.py	2011-10-31 08:44:21 +0000
@@ -58,34 +58,41 @@
         """
         Launch analytic distribution wizard from a statement line
         """
+        # Some verifications
         if not context:
             context = {}
         if isinstance(ids, (int, long)):
             ids = [ids]
-        # we get the analytical distribution object linked to this line
-        distrib_id = False
-        statement_line_obj = self.browse(cr, uid, ids[0], context=context)
-        amount = statement_line_obj.amount * -1 or 0.0
+        # Prepare some values
+        absl = self.browse(cr, uid, ids[0], context=context)
+        amount = absl.amount * -1 or 0.0
         # Search elements for currency
         company_currency = self.pool.get('res.users').browse(cr, uid, uid, context=context).company_id.currency_id.id
-        currency = statement_line_obj.statement_id.journal_id.currency and statement_line_obj.statement_id.journal_id.currency.id or company_currency
-        if statement_line_obj.analytic_distribution_id:
-            distrib_id = statement_line_obj.analytic_distribution_id.id
-        else:
-            distrib_id = self.pool.get('analytic.distribution').create(cr, uid, {}, context=context)
-            newvals={'analytic_distribution_id': distrib_id}
-            super(account_bank_statement_line, self).write(cr, uid, ids, newvals, context=context)
-        wiz_obj = self.pool.get('wizard.costcenter.distribution')
-        wiz_id = wiz_obj.create(cr, uid, {'total_amount': amount, 'distribution_id': distrib_id, 'currency_id': currency}, context=context)
-        # we open a wizard
+        currency = absl.statement_id.journal_id.currency and absl.statement_id.journal_id.currency.id or company_currency
+        # Get analytic distribution id from this line
+        distrib_id = absl.analytic_distribution_id and absl.analytic_distribution_id.id or False
+        # Prepare values for wizard
+        vals = {
+            'total_amount': amount,
+            'register_line_id': absl.id,
+            'currency_id': currency or False,
+            'state': 'dispatch',
+            'account_id': absl.account_id and absl.account_id.id or False,
+        }
+        if distrib_id:
+            vals.update({'distribution_id': distrib_id,})
+        # Create the wizard
+        wiz_obj = self.pool.get('analytic.distribution.wizard')
+        wiz_id = wiz_obj.create(cr, uid, vals, context=context)
+        # Update some context values
         context.update({
             'active_id': ids[0],
             'active_ids': ids,
-            'wizard_ids': {'cost_center': wiz_id},
         })
+        # Open it!
         return {
                 'type': 'ir.actions.act_window',
-                'res_model': 'wizard.costcenter.distribution',
+                'res_model': 'analytic.distribution.wizard',
                 'view_type': 'form',
                 'view_mode': 'form',
                 'target': 'new',

=== modified file 'analytic_distribution/wizard/analytic_distribution_wizard.py'
--- analytic_distribution/wizard/analytic_distribution_wizard.py	2011-10-27 14:58:18 +0000
+++ analytic_distribution/wizard/analytic_distribution_wizard.py	2011-10-31 08:44:21 +0000
@@ -303,6 +303,7 @@
         'purchase_line_id': fields.many2one('purchase.order.line', string="Purchase Order Line"),
         'invoice_id': fields.many2one('account.invoice', string="Invoice"),
         'invoice_line_id': fields.many2one('account.invoice.line', string="Invoice Line"),
+        'register_line_id': fields.many2one('account.bank.statement.line', string="Register Line"),
         'distribution_id': fields.many2one('analytic.distribution', string="Analytic Distribution"),
         'is_writable': fields.function(_is_writable, method=True, string='Is this wizard writable?', type='boolean', readonly=True, 
             help="This informs wizard if it could be saved or not regarding invoice state or purchase order state", store=False),
@@ -602,7 +603,7 @@
                 self.write(cr, uid, [wiz.id], {'distribution_id': distrib_id,}, context=context)
                 # link it to the element we come from (purchase order, invoice, purchase order line, invoice line, etc.)
                 for el in [('invoice_id', 'account.invoice'), ('invoice_line_id', 'account.invoice.line'), ('purchase_id', 'purchase.order'), 
-                    ('purchase_line_id', 'purchase.order.line')]:
+                    ('purchase_line_id', 'purchase.order.line'), ('register_line_id', 'account.bank.statement.line')]:
                     if getattr(wiz, el[0], False):
                         id = getattr(wiz, el[0], False).id
                         self.pool.get(el[1]).write(cr, uid, [id], {'analytic_distribution_id': distrib_id}, context=context)

=== modified file 'register_accounting/account_bank_statement.py'
--- register_accounting/account_bank_statement.py	2011-09-28 08:33:55 +0000
+++ register_accounting/account_bank_statement.py	2011-10-31 08:44:21 +0000
@@ -1024,6 +1024,23 @@
             move_line_obj.reconcile_partial(cr, uid, [st_line.from_import_cheque_id.id, move_line_id[0]], context=context)
         return True
 
+    def analytic_distribution_is_mandatory(self, cr, uid, id, context={}):
+        """
+        Verify that no analytic distribution is mandatory. It's not until one of test is true
+        """
+        # Some verifications
+        if isinstance(id, (list)):
+            id = id[0]
+        if not context:
+            context = {}
+        # Tests
+        absl = self.browse(cr, uid, id, context=context)
+        if absl.account_id.user_type.code in ['expense'] and not absl.analytic_distribution_id:
+            return True
+        elif absl.account_id.user_type.code in ['expense'] and not absl.analytic_distribution_id.cost_center_lines:
+            return True
+        return False
+
     def create(self, cr, uid, values, context={}):
         """
         Create a new account bank statement line with values
@@ -1086,7 +1103,7 @@
                 self.create_move_from_st_line(cr, uid, absl.id, absl.statement_id.journal_id.company_id.currency_id.id, '/', context=context)
 
             if postype == "hard":
-                if not absl.analytic_distribution_id and absl.account_id.user_type.code in ['expense'] and not context.get('from_yml'):
+                if self.analytic_distribution_is_mandatory(cr, uid, absl.id, context=context) and not context.get('from_yml'):
                     raise osv.except_osv(_('Error'), _('No analytic distribution found!'))
                 seq = self.pool.get('ir.sequence').get(cr, uid, 'all.registers')
                 self.write(cr, uid, [absl.id], {'sequence_for_reference': seq}, context=context)

